==> jc-1.4.0.tar.gz: soot/jimple/parser/CstPoolExtractor__24CstPoolExtractorWalker.h <==
// class soot.jimple.parser.CstPoolExtractor$CstPoolExtractorWalker

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 14864fc5fa26c5bd soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_analysis_DepthFirstAdapter

#include "soot/jimple/parser/analysis/DepthFirstAdapter.h"

#ifndef _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_
#define _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_parser_CstPoolExtractor$object;
struct _jc_soot_jimple_parser_node_AFullIdentClassName$object;
struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object;
struct _jc_soot_jimple_parser_node_AIdentClassName$object;
struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object;
struct _jc_soot_jimple_parser_node_AQuotedClassName$object;
struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object;
struct _jc_soot_jimple_parser_node_Start$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$_init$eccbe10ad531f023(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$inStart$fbfdfb7fbea23c69(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_Start$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAFullIdentClassName$432e7de8bbd4e7e8(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAFullIdentNonvoidType$e9f4e25e2bb95232(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAIdentClassName$22a3450a48e71f91(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAIdentNonvoidType$7a3a4ece69e01038(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAQuotedClassName$76d33878c91a6e4e(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAQuotedNonvoidType$1a544a35c550ed17(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$inStart$fbfdfb7fbea23c69;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAFullIdentClassName$432e7de8bbd4e7e8;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAFullIdentNonvoidType$e9f4e25e2bb95232;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAIdentClassName$22a3450a48e71f91;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAIdentNonvoidType$7a3a4ece69e01038;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAQuotedClassName$76d33878c91a6e4e;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAQuotedNonvoidType$1a544a35c550ed17;

// Virtual methods structure
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods {
	void	(*inStart$fbfdfb7fbea23c69)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_Start$object *);
	void	(*outAFullIdentClassName$432e7de8bbd4e7e8)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *);
	void	(*outAFullIdentNonvoidType$e9f4e25e2bb95232)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object *);
	void	(*outAIdentClassName$22a3450a48e71f91)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *);
	void	(*outAIdentNonvoidType$7a3a4ece69e01038)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object *);
	void	(*outAQuotedClassName$76d33878c91a6e4e)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *);
	void	(*outAQuotedNonvoidType$1a544a35c550ed17)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object *);
};

// Vtable
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs {
	struct _jc_soot_jimple_parser_CstPoolExtractor$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs {
    _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object {
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/CstPoolExtractor__24CstPoolExtractorWalker.h <==
// class soot.jimple.parser.CstPoolExtractor$CstPoolExtractorWalker

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 14864fc5fa26c5bd soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker
// @dep_class b43a9165b67db951 soot_jimple_parser_analysis_AnalysisAdapter
// @dep_class 49cf7a14fc836e70 soot_jimple_parser_analysis_DepthFirstAdapter

// header file dependencies
// @dep_header soot_jimple_parser_analysis_DepthFirstAdapter

#include "soot/jimple/parser/analysis/DepthFirstAdapter.h"

#ifndef _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_
#define _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_parser_CstPoolExtractor$object;
struct _jc_soot_jimple_parser_node_AFullIdentClassName$object;
struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object;
struct _jc_soot_jimple_parser_node_AIdentClassName$object;
struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object;
struct _jc_soot_jimple_parser_node_AQuotedClassName$object;
struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object;
struct _jc_soot_jimple_parser_node_Start$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs;
typedef struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object;

typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable;
typedef const struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype;

// Constructors
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$_init$eccbe10ad531f023(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_CstPoolExtractor$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$inStart$fbfdfb7fbea23c69(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_Start$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAFullIdentClassName$432e7de8bbd4e7e8(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAFullIdentNonvoidType$e9f4e25e2bb95232(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAIdentClassName$22a3450a48e71f91(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAIdentNonvoidType$7a3a4ece69e01038(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAQuotedClassName$76d33878c91a6e4e(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method$outAQuotedNonvoidType$1a544a35c550ed17(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$inStart$fbfdfb7fbea23c69;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAFullIdentClassName$432e7de8bbd4e7e8;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAFullIdentNonvoidType$e9f4e25e2bb95232;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAIdentClassName$22a3450a48e71f91;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAIdentNonvoidType$7a3a4ece69e01038;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAQuotedClassName$76d33878c91a6e4e;
extern _jc_method _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$method_info$outAQuotedNonvoidType$1a544a35c550ed17;

// Virtual methods structure
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods {
	void	(*inStart$fbfdfb7fbea23c69)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_Start$object *) _JC_JCNI_ATTR;
	void	(*outAFullIdentClassName$432e7de8bbd4e7e8)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentClassName$object *) _JC_JCNI_ATTR;
	void	(*outAFullIdentNonvoidType$e9f4e25e2bb95232)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AFullIdentNonvoidType$object *) _JC_JCNI_ATTR;
	void	(*outAIdentClassName$22a3450a48e71f91)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentClassName$object *) _JC_JCNI_ATTR;
	void	(*outAIdentNonvoidType$7a3a4ece69e01038)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AIdentNonvoidType$object *) _JC_JCNI_ATTR;
	void	(*outAQuotedClassName$76d33878c91a6e4e)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedClassName$object *) _JC_JCNI_ATTR;
	void	(*outAQuotedNonvoidType$1a544a35c550ed17)(_jc_env *, struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object *, struct _jc_soot_jimple_parser_node_AQuotedNonvoidType$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_analysis_AnalysisAdapter$vmethods	soot_jimple_parser_analysis_AnalysisAdapter;
	_jc_soot_jimple_parser_analysis_DepthFirstAdapter$vmethods	soot_jimple_parser_analysis_DepthFirstAdapter;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vmethods	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
};

// Vtype
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs {
	struct _jc_soot_jimple_parser_CstPoolExtractor$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs {
    _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_refs	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_refs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_refs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_analysis_AnalysisAdapter$sub_nonrefs	soot_jimple_parser_analysis_AnalysisAdapter;
    _jc_soot_jimple_parser_analysis_DepthFirstAdapter$sub_nonrefs	soot_jimple_parser_analysis_DepthFirstAdapter;
    _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$sub_nonrefs	soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker;
};

// Object instance structure
struct _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$object {
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype	*vtype;
	_jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$vtype _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker$class_object;

#endif	/* _JC_soot_jimple_parser_CstPoolExtractor__24CstPoolExtractorWalker_H_ */
